#
# $Id: Tools.pm,v 1.1 2006/12/05 21:20:19 gomor Exp $
#
package Net::Frame::Tools;
use strict;
use warnings;

our $VERSION = '1.00_03';

1;

__END__

=head1 NAME

Net::Frame::Tools - useful network utilities created using Net::Frame

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 AUTHOR

Patrice E<lt>GomoRE<gt> Auffret

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret

You may distribute this module under the terms of the Artistic license.
See LICENSE.Artistic file in the source distribution archive.

=cut
